<?php 
// app/Http/Controllers/LanguageController.php

namespace App\Http\Controllers\All;

use App\Models\Language;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class LanguageController extends Controller
{
    public function index()
    {
        $languages = Language::all();
        return view('user.languages.index', compact('languages'));
    }

    public function create()
    {
        return view('user.languages.create');
    }

    public function store(Request $request)
    {
        $request->validate([
            'code' => 'required|string|max:10|unique:languages',
            'name' => 'required|string|max:50|unique:languages',
            'is_default' => 'boolean',
        ], [
            'code.required' => 'The language code is required.',
            'code.max' => 'The language code must not exceed 10 characters.',
            'code.unique' => 'The language code has already been taken.',
            'name.required' => 'The language name is required.',
            'name.max' => 'The language name must not exceed 50 characters.',
            'name.unique' => 'The language name has already been taken.',
            'is_default.boolean' => 'The is default field must be a boolean value.',
        ]);

        $language = Language::create([
            'code' => $request->input('code'),
            'name' => $request->input('name'),
            'is_default' => $request->input('is_default', false),
        ]);

        if ($language->is_default) {
            // Update other languages to set 'is_default' to false
            Language::where('id', '!=', $language->id)->update(['is_default' => false]);
        }

        return redirect()->route('user.languages.index')->with('success', 'Language created successfully.');
    }


    public function edit($id)
    {
        $language = Language::findOrFail($id);
        return view('user.languages.edit', compact('language'));
    }

 
    public function update(Request $request, $id)
    {
        try {
 
            $request->validate([
                'code' => 'required|string|max:10|unique:languages,code,' . $id,
                'name' => 'required|string|max:50|unique:languages,name,' . $id,
             ]);
            
            $language = Language::findOrFail($id);

 
            $language->update([
                'code' => $request->input('code'),
                'name' => $request->input('name'),
                'is_default' => $request->has('is_default') && $request->input('is_default') === 'on',
            ]);

             

            if ($language->is_default) {
                Language::where('id', '!=', $language->id)->update(['is_default' => false]);
            }

 
            return redirect()->route('user.languages.index')->with('success', 'Language updated successfully.');
        } catch (\Exception $e) {
           // dd($request->all());
            dd($e->getMessage(), $e->getTraceAsString());
            \Illuminate\Support\Facades\Log::error('Error during language update', ['error' => $e->getMessage(), 'trace' => $e->getTraceAsString()]);
            return redirect()->back()->with('error', 'An error occurred during the update.');
        }
    }

    public function destroy($id)
    {
        $language = Language::findOrFail($id);
        $language->delete();

        return redirect()->route('user.languages.index')->with('success', 'Language deleted successfully.');
    }

    public function allLanguages()
    {
        $languages = Language::get(['id','name','code', 'is_default']);
        return response()->json(array('status' => 'success','message' => 'Data found', 'result' => $languages));
    }
}

?>