<?php 
// app/Http/Controllers/McqCategoryController.php

namespace App\Http\Controllers\All;
use Illuminate\Support\Facades\DB;
use App\Models\Language;
use App\Models\McqCategory;
use App\Models\McqCategoryTranslation;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class McqCategoryController extends Controller
{
    public function index()
    {
       
        $defaultLanguage = Language::where('is_default', true)->value('id') ?? 1;
        $mcqCategory = McqCategoryTranslation::where('language_id', $defaultLanguage)->get();
        return view('user.mcqCategory.index', compact('mcqCategory'));
    }

    public function create()
    {
        $languages = Language::all();
        return view('user.mcqCategory.create', compact('languages'));
    }

    public function store(Request $request)
    {
        // Validate the incoming request data
        $request->validate([
            'names.*' => 'required|string', // Validation for category names in multiple languages
        ]);

        // Create a new MCQ category
        $mcqCategory = McqCategory::create();

        // Store category names in multiple languages
        foreach ($request->input('names') as $languageCode => $name) {
            // Find the language ID based on the language code
            $languageId = Language::where('code', $languageCode)->value('id');
            
            McqCategoryTranslation::create([
                'category_id' => $mcqCategory->id,
                'language_id' => $languageId,
                'name' => $name,
            ]);
        }
    
        // Redirect back with a success message
        return redirect()->route('user.mcqCategory.index')->with('success', 'MCQ Category added successfully');
    }

    public function edit($id)
    {
        
        $mcqCategory = McqCategory::findOrFail($id);
        $languages = Language::all();

        // // Load translations for the existing MCQ category
        $translations = $mcqCategory->translations->pluck('name', 'language_id')->toArray();

        return view('user.mcqCategory.edit', compact('mcqCategory', 'languages', 'translations'));
    }

 
    public function update(Request $request, $id)
    {
        // Validate the incoming request data
        $request->validate([
            'names.*' => 'required|string', // Validation for category names in multiple languages
        ]);
    
        // Find the MCQ category by ID
        $mcqCategory = McqCategory::findOrFail($id);
    
        // Update category names in multiple languages
        foreach ($request->input('names') as $languageCode => $name) {
            // Find the language ID based on the language code
            $languageId = Language::where('code', $languageCode)->value('id');
    
            // Update or create the translation record
            $translation = McqCategoryTranslation::updateOrCreate(
                ['category_id' => $mcqCategory->id, 'language_id' => $languageId],
                ['name' => $name]
            );
        }
    
        // Redirect back with a success message
        return redirect()->route('user.mcqCategory.index')->with('success', 'MCQ Category updated successfully');
    }



    public function destroy($id)
    {
        // Find the MCQ category by ID
        $mcqCategory = McqCategory::findOrFail($id);
    
        // Delete translations associated with the category
        $mcqCategory->translations()->delete();
    
        // Delete the MCQ category
        $mcqCategory->delete();
    
        // Redirect back with a success message
        return redirect()->route('user.mcqCategory.index')->with('success', 'MCQ Category deleted successfully');
    }

    public function allCategories(Request $request)
    {
        if(trim($request->languageId) == ""){
            return response()->json(array('status' => 'error','message' => 'Enter languageId', 'result' => []));
        }
        $mcqCategory = McqCategoryTranslation::where('language_id', $request->languageId)->get(['name', 'category_id']);
        return response()->json(array('status' => 'success','message' => 'Data found', 'result' => $mcqCategory));
    }
}

?>