<?php

// Facades
use Illuminate\Support\Facades\{
    Auth,
    Route
};

// Admin Restful Controllers
use App\Http\Controllers\All\ProfileController;
use App\Http\Controllers\All\PageController;
use App\Http\Controllers\All\CmsController;
use App\Http\Controllers\All\ContentsController;
use App\Http\Controllers\All\ArticleController;
use App\Http\Controllers\All\ReferenceController;
use App\Http\Controllers\HomeController;


use App\Http\Controllers\Admin\{
    ActivityLogController,
    DashboardController,
    UserController
};

// USer - Restful Controllers
use App\Http\Controllers\User\{
    ActivityLogController as UserActivityLogController,
    DashboardController as UserDashboardController,
};

// Shared Restful Controllers
use App\Http\Controllers\All\{
    TmpImageUploadController
};

Route::get('/', [HomeController::class, 'index'])->name('home.index');
Route::get('/api', [HomeController::class, 'api'])->name('home.api');
Route::get('/page/{slug}', [HomeController::class, 'page'])->name('home.page');


// Admin
Route::group(['middleware' => ['auth', 'admin'], 'prefix' => 'admin', 'as' => 'admin.'],function() {
    Route::resource('dashboard', DashboardController::class);
    Route::resource('user', UserController::class);
    Route::resource('activity', ActivityLogController::class);
});


// User
Route::group(['middleware' => ['auth'], 'prefix' => 'user', 'as' => 'user.'],function() {
        Route::resource('dashboard', UserDashboardController::class);
        Route::resource('activity', UserActivityLogController::class);

        Route::get('/admin/cms', [CmsController::class, 'edit'])->name('cms.edit');
        Route::put('/admin/cms/update', [CmsController::class, 'update'])->name('cms.update');

        Route::get('/admin/page', [PageController::class, 'index'])->name('page.index');
        Route::get('/admin/page/create', [PageController::class, 'create'])->name('page.create');
        Route::post('/admin/page/store', [PageController::class, 'store'])->name('page.store');
        Route::get('/admin/page/edit/{id}', [PageController::class, 'edit'])->name('page.edit');
        Route::put('/admin/page/update/{id}', [PageController::class, 'update'])->name('page.update');
        Route::delete('/admin/page/destroy/{id}', [PageController::class, 'destroy'])->name('page.destroy');

        Route::get('/admin/contents', [ContentsController::class, 'index'])->name('contents.index');
        Route::get('/admin/contents/create', [ContentsController::class, 'create'])->name('contents.create');
        Route::post('/admin/contents/store', [ContentsController::class, 'store'])->name('contents.store');
        Route::get('/admin/contents/edit/{id}', [ContentsController::class, 'edit'])->name('contents.edit');
        Route::put('/admin/contents/update/{id}', [ContentsController::class, 'update'])->name('contents.update');
        Route::delete('/admin/contents/destroy/{id}', [ContentsController::class, 'destroy'])->name('contents.destroy');

        Route::get('/admin/article', [ArticleController::class, 'index'])->name('article.index');
        Route::get('/admin/article/create', [ArticleController::class, 'create'])->name('article.create');
        Route::post('/admin/article/store', [ArticleController::class, 'store'])->name('article.store');
        Route::get('/admin/article/edit/{id}', [ArticleController::class, 'edit'])->name('article.edit');
        Route::put('/admin/article/update/{id}', [ArticleController::class, 'update'])->name('article.update');
        Route::delete('/admin/article/destroy/{id}', [ArticleController::class, 'destroy'])->name('article.destroy');
        
        Route::get('/admin/reference', [ReferenceController::class, 'index'])->name('reference.index');
        Route::get('/admin/reference/create', [ReferenceController::class, 'create'])->name('reference.create');
        Route::post('/admin/reference/store', [ReferenceController::class, 'store'])->name('reference.store');
        Route::get('/admin/reference/edit/{id}', [ReferenceController::class, 'edit'])->name('reference.edit');
        Route::post('/admin/reference/update/{id}', [ReferenceController::class, 'update'])->name('reference.update');
        Route::delete('/admin/reference/destroy/{id}', [ReferenceController::class, 'destroy'])->name('reference.destroy');
});

// Auth
Route::group(['middleware' => ['auth']],function() {
    // TMP FILE UPLOAD
    Route::delete('tmp_upload/revert', [TmpImageUploadController::class, 'revert']);
    Route::post('tmp_upload/content', [TmpImageUploadController::class, 'faqImageUpload'])->name('tmpupload.faqImageUpload');
    Route::resource('tmp_upload', TmpImageUploadController::class);
    Route::resource('profile', ProfileController::class)->parameter('profile', 'user');;
  
});

Auth::routes(['register' => false]);